body {
  margin: 10px;
  font-family: 'PT Sans', sans-serif;
  padding-top: 3rem;
  padding-bottom: 3rem;
/*  color: #5a5a5a;*/
/*        font-size: 1.5vw;*/
  background-color:rgb(90, 90, 90);
}

ul {
  padding-left: 12px;
  list-style: none;
  list-style-type: none;
}

ul li ul {
  display: none;
  padding-left: 12px;
  list-style: none;
  list-style-type: none;
}

.sidebar ul {
  list-style: none;
  list-style-type: none;
}

header input {
  max-height: 30px;
  padding-top: 5px;
  margin-top: 10px;
}

.sidebar {
  background-color:rgb(90, 90, 90);
  color: white;
  font-size: 13px;
}

.sidebar a {
  color: white;
}

.col-md-10 a {
  color: white;
}

.col-md-9 a {
  color: white;
}

.nav-narrow {
  max-height: 20;
  padding-top: 0px;
  padding-bottom: 0px;
}

